/******************************************************************************
*
* (c) 2006 by BECK IPC GmbH
*
*******************************************************************************
*
* Disclaimer: This program is an example and should be used as such.
*             If you wish to use this program or parts of it in your application,
*             you must validate the code yourself. BECK IPC GmbH can not be held
*             responsible for the correct functioning or coding of this example.
*
* Module:     fdisk.h
*
* Function:   See fdisk.c
*
*******************************************************************************
*
* $Header: c:\prjPib\IPC@CHIP\Examples\extdisk\FDISK\Source\fdisk.h, 8, 05.01.2007 08:37:54, Jan Schatz$
*
******************************************************************************/



#ifndef _FDISK_H_
#define _FDISK_H_



#include "bool.h"
#include "extlib.h"



/******************************************************************************
* Definition of constants
******************************************************************************/
// Partition type IDs
#define FDISK_T_UNKNOWN                   0x00  // Unknown type or not set
#define FDISK_T_FAT12                     0x01  // FAT 12 bit
#define FDISK_T_FAT16S		               0x04  // FAT 16 bit (Partition smaller than 32MB)
#define FDISK_T_EXTENDED                  0x05  // Extended DOS partition
#define FDISK_T_FAT16L                    0x06  // FAT 16 bit (Partition larger than 32MB)
#define FDISK_T_FAT32                     0x0B  // FAT 32 bit
#define FDISK_T_FAT32_LBA                 0x0C  // FAT 32 bit with LBA extension
#define FDISK_T_FAT16L_LBA                0x0E  // FAT 16 bit (Partition larger than 32B)
                                                // with LBA extension
#define FDISK_T_EXTENDED_LBA              0x0F  // Extended DOS partition with LBA extension
// Size of one partition etry in MBR
// Nedded because TPartition-structure has different size and format
#define PARTITION_ENTRY_SIZE              16
// Maximum number of cylinders, heads and sectors for a drive
#define FDISK_MAX_N_CYLINDERS             1023
#define FDISK_MAX_N_HEADS                 255
#define FDISK_MAX_N_SECTORS               63



/******************************************************************************
* Definition of types
******************************************************************************/
// Here the information on one partition is kept.
typedef struct TPartition_
{
  unsigned char bootState;       // 0x80 if bootable else 0x00
  unsigned char startHead;       // Start head
  unsigned char startSector;     // Start sector
  unsigned short startCylinder;  // Start cylinder
  unsigned char typeId;          // Partition type
  unsigned char endHead;         // End head
  unsigned char endSector;       // End sector
  unsigned short endCylinder;    // End cylinder
  unsigned long startLSector;    // Start sector (logical)
  unsigned long nSectors;        // Number of sectors in partiion
} TPartition;



// Here the information on the Master Boot Record is kept.
// Use the function fdiskReadMbr to fill the structure and fdiskWriteMbr to
// write it back to disk.
typedef struct TMasterBootRecord_
{
  unsigned char fill[0x01BE];     // Boot code
  TPartition partition[4];        // 4 partition entries
  unsigned char mbrSignature[2];  // 0x55, 0xAA marks MBR
} TMasterBootRecord;


/******************************************************************************
* Prototypes
******************************************************************************/
FdiskBool fdiskCheckInterfaceVersion( void );
unsigned long fdiskPhysicToLogic( unsigned short cylinder,
                                  unsigned short head,
                                  unsigned short sector );
void fdiskLogicToPhysic( unsigned long logicalSector,
                         unsigned short *cylinder,
                         unsigned short *head,
                         unsigned short *sector );
FdiskBool fdiskReadMbr( unsigned char drive );
FdiskBool fdiskCheckMbr( void );
FdiskBool fdiskWriteMbr( void );
FdiskBool fdiskClearMbr( void );
unsigned char fdiskGetFirstFreePartition( void );
unsigned long fdiskGetFirstFreeSector( void );
unsigned long fdiskGetLastFreeSector( void );
unsigned short fdiskCreatePartition( unsigned long nSectors,
                                     unsigned char typeID,
                                     FdiskBool bootable );
FdiskBool fdiskDeletePartition( unsigned char partitionNumber );
FdiskBool fdiskGetPartitionData( unsigned char partitionNumber,
                                 TPartition *partition );
FdiskBool fdiskSetPartitionData( unsigned char partitionNumber,
                                 TPartition *partition );



#endif
// End of file

